<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Rendszerfigyelő</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>A Rendszerfigyelő egy eszköz, a valós idejű rendszerterhelés figyelemmel kísérésére, a rendszeren futó folyamatok és szolgáltatások megtekintésére és vezérlésére.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Részletek elrejtése</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>Általános kihasználtság</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>Egyéni kihasználtság</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Olvasás</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Írás</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 másodperc</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 nap %2 óra %3 perc</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Hasznosítás</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Jelenlegi frekvencia</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frekvencia</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Kereskedő</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Foglalatok</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Logikai processzor</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtualizáció</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1i gyorsítótár</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1d gyorsítótár</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2 gyorsítótár</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3 gyorsítótár</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Terhelési átlag</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Fájlleírók</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Folyamatok</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Szálak</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Gazda név</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Operációs rendszer típusa</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzió</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Futásidő</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 másodperc</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Nincs keresési eredmény</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Részletek</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Részletek</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>aktív</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>újratöltés</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>inaktív</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>sikertelen</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>aktiválás</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>felfüggesztés</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>gyomlálás</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>nem található</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>rosszul beállított</translation>
    </message>
    <message>
        <source>error</source>
        <translation>hiba</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>egyesített</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>maszkolt</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>betöltött</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>Nincs adat</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Kézi</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>engedélyezve</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>tiltva</translation>
    </message>
    <message>
        <source>static</source>
        <translation>statikus</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>átmeneti</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>közvetett</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>engedélyezett futásidő</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>maszkolt</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>fejlesztett</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>halott</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>előre indít</translation>
    </message>
    <message>
        <source>start</source>
        <translation>indít</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>utána indít</translation>
    </message>
    <message>
        <source>running</source>
        <translation>futó</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>kilépett</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>újratölt</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>megállít</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>watchdog leállítás</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>sigterm leállítás</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>sigkill leállítás</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>utána megállít</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>végső sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>végső sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>sikertelen</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>automatikus újraindítás</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Használt</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Elérhető</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Megosztott</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>Gyorsítótárazott</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Pufferek</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Gyorsítótárazott cserehely</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktív</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Tétlen</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Szennyezett</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Feltérképezett</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Teljes cserehely</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Szabad cserehely</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Tömb</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Modell</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Olvasási sebesség</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Írási sebesség</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Kapacitás</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Olvasott szektorok</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Olvasások/mp</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Olvasott szektorok/mp</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Összevont olvasások/mp</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Írt szektorok</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Az írások befejeződtek</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Összevont írások</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Írások/mp</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Írt szektorok/mp</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Összevont írások/mp</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Rendszer</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Parancsikonok megjelenítése</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>A folyamat befejezése adatvesztést okozhat.
Biztos benne, hogy folytatni akarja?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Folyamat befejezése</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>A folyamat kényszerített befejezése adatvesztést okozhat.
Biztos benne, hogy folytatni akarja?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Az alkalmazás kényszerített befejezése adatvesztést okozhat. Biztos benne, hogy folytatja?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Kényszerített befejezés</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Befejezés</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>IP cím:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Hálózati maszk:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Adás:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Előtag hossza:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Hatókör:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Csatlakozás típusa</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Link minősége</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Jelerősség</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Zajszint</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Sávszélesség</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>RX csomagok</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>RX bájtok</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>RX hibák</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX eldobások</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>RX túlfutások</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>RX keret</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>TX csomagok</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>TX bájtok</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>TX hibák</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>TX túlfutások</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>TX szállító</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX eldobások</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Parancssor</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Kezdési idő</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Kattintson a bezárni kívánt alkalmazásra</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Fogadás</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>Processzor</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lemez olvasás</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Lemez írás</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Cserehely</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Nincs engedélyezve</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Letöltés</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Feltöltés</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Összes beérkezett</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Összes küldött</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Küldés</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Lemezek</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Nagyon magas</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Magas</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normál</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Alacsony</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Nagyon alacsony</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Egyéni</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Érvénytelen</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Hiba: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Nem sikerült megváltoztatni a folyamat prioritását</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Alkalmazások</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Saját folyamatok</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Minden folyamat</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>Betöltés</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Nem sikerült szüneteltetni a folyamatot</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Nem sikerült folytatni a folyamatot</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Nem sikerült kilőni a folyamatot</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Ismeretlen hiba</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Nem sikerült elküldeni a jelet a feldolgozáshoz</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Nem sikerült befejezni a folyamatokat</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 alkalmazás és %2 folyamat fut)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Nem válaszol</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Felfüggesztés</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Tálca</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>A parancs helyének megtekintése</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Tulajdonságok</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Folyamat leállítása</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Folyamat folytatása</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Folyamat kilövése</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Prioritás megváltoztatása</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Folyamat felfüggesztése</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Egyedi prioritás</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Változtatás</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>Processzor</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Lemez írás</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lemez olvasás</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Letöltés</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Feltöltés</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Felhasználó</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nagyszerű</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioritás</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Megosztott memória</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Virtuális memória</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Nem támogatott</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Rendszervédelem</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Figyelmeztetések megjelenítése, ha a használat meghaladja a küszöbértékeket</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Értesítések</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>Processzor figyelmeztetési küszöbérték (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>Memória figyelmeztetési küszöbérték (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>Figyelmeztetési időköz (perc)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>A szolgáltatás indítási típusának beállítása sikertelen</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Hiba: Nem sikerült beállítani a szolgáltatás indítási típusát az összeomlott alfolyamat miatt.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Szolgáltatási példány neve</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Indítás</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Kézi</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Indítási típus</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Betöltés</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktív</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Al</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Indítási típus</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(Módosítható)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Tartomány: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Kényszerített alkalmazás leállítás</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Kibővített</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Tömörített</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Nézet</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Folyamatok</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Szolgáltatások</translation>
    </message>
</context>
</TS>
